@@ -37,7 +37,11 @@ main(int argc, char **argv, char **env)
     if (!do_undump) {
 	my_perl = perl_alloc();
 	if (!my_perl)
+#ifdef VMS
+	    exit(vaxc$errno);
+#else
 	    exit(1);
+#endif
 	perl_construct( my_perl );
     }
 
@@ -56,7 +60,11 @@ main(int argc, char **argv, char **env)
 #endif
 	if (!fp) {
 	    perror(argv[1]);
+#ifdef VMS
+	    exit(vaxc$errno);
+#else
 	    exit(1);
+#endif
 	}
 	argv++;
 	argc--;
